@@ -3,7 +3,7 @@
 #
 # Interface to Clipper C++ code
 #
-#  $Revision: 1.13 $ $Date: 2016/03/24 00:52:57 $
+#  $Revision: 1.14 $ $Date: 2018/03/01 13:35:53 $
 #
 
 validxy <- function(P) {
@@ -224,3 +224,28 @@ polyminkowski <-
                     A, B, closed, x0, y0, eps)
     return(aspolygonlist(result))
   }
+
+pointinpolygon <-
+  function(P, A, eps, x0, y0) {
+    # validate arguments
+    if(!validxy(P))
+      stop("Argument P should be a list containing vectors x,y")
+    if(!validxy(A))
+      stop("Argument A should be a list containing vectors x,y")
+    # determine value of 'eps' if missing
+    if(missing(eps) || missing(x0) || missing(y0)) {
+      xr <- xrange(A)
+      yr <- yrange(A)
+      if(missing(eps)) eps <- max(diff(xr), diff(yr))/1e9
+      if(missing(x0)) x0 <- mean(xr)
+      if(missing(y0)) y0 <- mean(yr)
+    } 
+    # call clipper library
+    A <- ensurexydouble(A)
+    P <- ensurexydouble(P)
+    storage.mode(x0) <- storage.mode(y0) <- storage.mode(eps) <- "double"
+    ans <- .Call("Cpiptest",
+                 P, A,
+                 x0, y0, eps)
+    return(ans)
+  }
